@@ -3,10 +3,11 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: SQLite setup/teardown for tests
 
-our $VERSION = '0.0400';
+our $VERSION = '0.0401';
 
 use Moo;
 use strictures 2;
+use namespace::clean;
 
 use DBI;
 use File::Copy;
@@ -129,7 +130,7 @@ Test::SQLite - SQLite setup/teardown for tests
 
 =head1 VERSION
 
-version 0.0400
+version 0.0401
 
 =head1 SYNOPSIS
 
@@ -149,7 +150,7 @@ version 0.0400
   $dbh->disconnect;
 
   # Copy a database file to the test db:
-  $sqlite = Test::SQLite->new(database => '/some/where/production.db');
+  $sqlite = Test::SQLite->new(database => '/some/where/database.db');
   $dbh = $sqlite->dbh;
   # Fiddle with the test database...
   $dbh->disconnect;
@@ -167,7 +168,7 @@ version 0.0400
 
 =head1 DESCRIPTION
 
-C<Test::SQLite> is loosely inspired by L<Test::PostgreSQL> and
+C<Test::SQLite> is inspired by L<Test::PostgreSQL> and
 L<Test::mysqld>, and creates a temporary db to use in tests.
 
 This module will also return the database B<dbh> handle, B<dsn>
